@@ -1,11 +1,11 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       PROGRAM COLOR2
 
       PARAMETER( NMAX=50 )
       REAL      X(0:NMAX), Y(0:NMAX)
-      CHARACTER CSGI*1, CTTL*32
+      CHARACTER USGI*3, CTTL*32
 
       R    = 3.7
       X(0) = 1950
@@ -43,7 +43,7 @@
 
       CALL UYAXDV( 'L', 0.1, 0.5 )
       CALL UYAXDV( 'R', 0.1, 0.5 )
-      CTTL = CSGI(131) // 'T [K]'
+      CTTL = USGI(131) // 'T [K]'
       CALL UYSTTL( 'L',CTTL, 0. )
 
       CALL UXMTTL( 'T', 'INTERANNUAL VARIATION', 0. )
